Method: JSS::Computer.inventory_collection_settings

Defined in:
lib/jss/api_object/computer.rb

.inventory_collection_settings(api: JSS.api) ⇒ Hash

Display the current Computer Inventory Collection settings in the JSS. Currently this is read-only in ruby-jss, even tho the API allows updating.

Parameters:

Returns:

  • (Hash)

    the Computer Inventpry Collection Settings from the currently connected JSS.



303
304
305
# File 'lib/jss/api_object/computer.rb', line 303

def self.inventory_collection_settings(api: JSS.api)
  api.get_rsrc(INV_COLLECTION_RSRC)[INV_COLLECTION_KEY]
end