Method: JSS::Computer#distribution_point

Defined in:
lib/jss/api_object/computer.rb

#distribution_pointString (readonly)

Returns The name of the distribution point for this computer.

Returns:

  • (String)

    The name of the distribution point for this computer



527
528
529
# File 'lib/jss/api_object/computer.rb', line 527

def distribution_point
  @distribution_point
end