Method: JSS::Computer#mdm_capable_users

Defined in:
lib/jss/api_object/computer.rb

#mdm_capable_usersArray (readonly)

Returns user accts that support MDM? NOTE: This suffers from the JSON-Hash-treated-like_XML-Array-loses-data bug and only shows the last listed user, cuz it comes from the API as a hash, not an array.

Returns:

  • (Array)

    user accts that support MDM? NOTE: This suffers from the JSON-Hash-treated-like_XML-Array-loses-data bug and only shows the last listed user, cuz it comes from the API as a hash, not an array.



567
568
569
# File 'lib/jss/api_object/computer.rb', line 567

def mdm_capable_users
  @mdm_capable_users
end