Method: JSS::Computer#netboot_server

Defined in:
lib/jss/api_object/computer.rb

#netboot_serverString (readonly)

Returns the name of the netboot server for this machine.

Returns:

  • (String)

    the name of the netboot server for this machine



570
571
572
# File 'lib/jss/api_object/computer.rb', line 570

def netboot_server
  @netboot_server
end