Method: JSS::Computer#set_management_to
- Defined in:
- lib/jss/api_object/computer.rb
#set_management_to(name, password) ⇒ void Also known as: make_managed
This method returns an undefined value.
Set or unset management acct and password for this computer
The changes will need to be pushed to the server with #update before they take effect.
CAUTION: this does nothing to confirm the name and password will work on the machine!
1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/jss/api_object/computer.rb', line 1013 def set_management_to(name, password) password = nil unless name @management_username = name @management_password = password @managed = name ? true : false @need_to_update = true end |