Method: JSS::Computer#sus

Defined in:
lib/jss/api_object/computer.rb

#susString (readonly)

Returns the name of the Software Update Server assigned to this machine.

Returns:

  • (String)

    the name of the Software Update Server assigned to this machine.



585
586
587
# File 'lib/jss/api_object/computer.rb', line 585

def sus
  @sus
end