Method: JSS::ComputerExtensionAttribute#platform

Defined in:
lib/jss/api_object/extension_attribute/computer_extension_attribute.rb

#platformString

When the @input_type is “script”, The platform on which a script will run.

NOTE: The web app seems to let you have both Mac and Windows scripts defined when the type is “script”, however the API will only return the Mac script info if both are defined. DEPRECATED: windows EAs are no longer supported

Returns:



101
102
103
# File 'lib/jss/api_object/extension_attribute/computer_extension_attribute.rb', line 101

def platform
  @platform
end