Method: JSS::Locatable#location

Defined in:
lib/jss/api_object/locatable.rb

#locationHash<String>

All the location data in a Hash, as it comes from the API.

The reason it isn’t stored this way is to prevent editing of the hash directly.

Returns:



140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/jss/api_object/locatable.rb', line 140

def location
  {
    :building => @building,
    :department => @department,
    :email_address => @email_address,
    :phone => @phone,
    :position => @position,
    :real_name => @real_name,
    :room => @room,
    :username => @username
  }
end