Method: JSS::ManagementHistory::MDMCommand#completed

Defined in:
lib/jss/api_object/management_history/mdm_command.rb

#completedTime

Returns When the command completed, as a ruby Time object.

Returns:

  • (Time)

    When the command completed, as a ruby Time object



106
107
108
# File 'lib/jss/api_object/management_history/mdm_command.rb', line 106

def completed
  JSS.epoch_to_time @completed_epoch if @completed_epoch
end