Method: JSS::ManagementHistory::MDMCommand#issued

Defined in:
lib/jss/api_object/management_history/mdm_command.rb

#issuedTime

Returns When the command was issued, as a ruby Time object.

Returns:

  • (Time)

    When the command was issued, as a ruby Time object



92
93
94
# File 'lib/jss/api_object/management_history/mdm_command.rb', line 92

def issued
  JSS.epoch_to_time @issued_epoch if @issued_epoch
end