Method: JSS::ManagementHistory::MDMCommand#issued_epoch

Defined in:
lib/jss/api_object/management_history/mdm_command.rb

#issued_epochInteger (readonly)

Returns When the command was issued, as a unix epoch timestamp with milliseconds.

Returns:

  • (Integer)

    When the command was issued, as a unix epoch timestamp with milliseconds



# File 'lib/jss/api_object/management_history/mdm_command.rb', line 73