Method: JSS::ManagementHistory::MobileDeviceApp#bundle_size

Defined in:
lib/jss/api_object/management_history/mobile_device_app.rb

#bundle_sizeString (readonly)

Returns The size of the app bundle as text, e.g. ‘28 MB’.

Returns:

  • (String)

    The size of the app bundle as text, e.g. ‘28 MB’



# File 'lib/jss/api_object/management_history/mobile_device_app.rb', line 69