Method: JSS::ManagementHistory::UserLocationChange#date_time

Defined in:
lib/jss/api_object/management_history/user_location_change.rb

#date_timeTime

Returns When the change occurred, as a ruby Time object.

Returns:

  • (Time)

    When the change occurred, as a ruby Time object



85
86
87
# File 'lib/jss/api_object/management_history/user_location_change.rb', line 85

def date_time
  JSS.epoch_to_time @date_time_epoch if @date_time_epoch
end