Method: JSS::MobileDevice#airplay_password

Defined in:
lib/jss/api_object/mobile_device.rb

#airplay_passwordString (readonly)

Returns the airplay passwd on devices that can receive AirPlay (i.e. apple tvs).

Returns:

  • (String)

    the airplay passwd on devices that can receive AirPlay (i.e. apple tvs)



244
245
246
# File 'lib/jss/api_object/mobile_device.rb', line 244

def airplay_password
  @airplay_password
end