Method: JSS::Policy#locate_file

Defined in:
lib/jss/api_object/policy.rb

#locate_fileString

Returns The term to seach for using the locate command.

Returns:

  • (String)

    The term to seach for using the locate command



1107
1108
1109
# File 'lib/jss/api_object/policy.rb', line 1107

def locate_file
  @files_processes[:locate_file]
end