Method: JSS::Policy#printer_names

Defined in:
lib/jss/api_object/policy.rb

#printer_namesArray

Returns the names of the printers handled by the policy.

Returns:

  • (Array)

    the names of the printers handled by the policy



1317
1318
1319
1320
1321
1322
1323
# File 'lib/jss/api_object/policy.rb', line 1317

def printer_names
    begin
        @printers.map { |p| p[:name] }
        rescue TypeError
        return []
    end
end