Method: JSS::Policy#script_names

Defined in:
lib/jss/api_object/policy.rb

#script_namesArray

Returns the names of the scripts handled by the policy.

Returns:

  • (Array)

    the names of the scripts handled by the policy



1201
1202
1203
# File 'lib/jss/api_object/policy.rb', line 1201

def script_names
  @scripts.map { |p| p[:name] }
end