Method: JSS::Policy#set_search_for_process

Defined in:
lib/jss/api_object/policy.rb

#set_search_for_process(process, kill = false) ⇒ void

This method returns an undefined value.

Set the process name to search for, and if it should be killed if found.

Setter methods (which end with =) can’t easily take multiple arguments, so we instead name them “set_blah_blah” rather than “blah_blah=”

Parameters:

  • process (String)

    the process name to search for

  • kill (Boolean) (defaults to: false)

    should be process be killed if found



1045
1046
1047
1048
1049
# File 'lib/jss/api_object/policy.rb', line 1045

def set_search_for_process(process, kill = false)
  @files_processes[:search_for_process] = process.to_s
  @files_processes[:kill_process] = kill ? true : false
  @need_to_update = true
end