Method: JSS::Scopable#parse_scope
- Defined in:
- lib/jss/api_object/scopable.rb
#parse_scope ⇒ void
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
This method returns an undefined value.
Call this during initialization of objects that have a scope and the scope instance will be created from @init_data
77 78 79 80 |
# File 'lib/jss/api_object/scopable.rb', line 77 def parse_scope @scope = JSS::Scopable::Scope.new self.class::SCOPE_TARGET_KEY, @init_data[:scope] @scope.container = self end |