Method: JSS::User#sites

Defined in:
lib/jss/api_object/user.rb

#sitesArray<Hash> (readonly)

Unlike every other Sitable object, Users can be in multiple sites, so we don’t use the Sitable mixin module. Instead we’ll we’ll store them in this Array, as they come from the API.

Each Hash has the :id and :name for one site

Returns:



114
115
116
# File 'lib/jss/api_object/user.rb', line 114

def sites
  @sites
end