Method: JSS::ComputerExtensionAttribute#script

Defined in:
lib/jss/api_object/extension_attribute/computer_extension_attribute.rb

#scriptString Also known as: code

Returns the script code that will be executed when the @input_type is “script”,.

Returns:

  • (String)

    the script code that will be executed when the @input_type is “script”,



118
119
120
# File 'lib/jss/api_object/extension_attribute/computer_extension_attribute.rb', line 118

def script
  @script
end