Class: JSS::ManagementHistory::UserLocationChange

Inherits:
Object
  • Object
show all
Includes:
HashLike
Defined in:
lib/jss/api_object/management_history/user_location_change.rb

Overview

UserLocationChange - a change in a device's assigned user or location

This should only be instantiated by the ManagementHistory.user_location_history method when mixed in to Computers or Mobile devices.

That method will return an array of these objects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#building ⇒ String (readonly)

Returns The building for this change.

Returns:

  • (String) —

    The building for this change



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 74

#date_time_epoch ⇒ Integer (readonly)

Returns When the change occurred.

Returns:

  • (Integer) —

    When the change occurred



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 52

#department ⇒ String (readonly) Also known as: dept

Returns The department for this change.

Returns:

  • (String) —

    The department for this change



72
# File 'lib/jss/api_object/management_history/user_location_change.rb', line 72

alias dept department

#email_address ⇒ String (readonly) Also known as: email

Returns The email_address for this change.

Returns:

  • (String) —

    The email_address for this change



64
# File 'lib/jss/api_object/management_history/user_location_change.rb', line 64

alias email email_address

#full_name ⇒ String (readonly)

Returns The user's full name for this change.

Returns:

  • (String) —

    The user's full name for this change



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 58

#phone_number ⇒ String (readonly)

Returns The phone_number for this change.

Returns:

  • (String) —

    The phone_number for this change



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 66

#position ⇒ String (readonly)

Returns The position for this change.

Returns:

  • (String) —

    The position for this change



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 80

#room ⇒ String (readonly)

Returns The room for this change.

Returns:

  • (String) —

    The room for this change



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 77

#username ⇒ String (readonly)

Returns The username for this change.

Returns:

  • (String) —

    The username for this change



# File 'lib/jss/api_object/management_history/user_location_change.rb', line 55

Instance Method Details

#[](attr) ⇒ Object Originally defined in module HashLike

#date_time ⇒ Time

Returns When the change occurred, as a ruby Time object.

Returns:

  • (Time) —

    When the change occurred, as a ruby Time object



85
86
87
# File 'lib/jss/api_object/management_history/user_location_change.rb', line 85

def date_time
  JSS.epoch_to_time @date_time_epoch if @date_time_epoch
end