Class: JSS::Package

Inherits:
APIObject show all
Includes:
Creatable, Updatable
Defined in:
lib/jss/api_object/package.rb,
lib/jss.rb

Overview

A Package in the JSS

Also the API provides no access to the package’s file list (index), so indexing must be done separately (usually via Casper Admin)

See Also:

Constant Summary collapse

RSRC_BASE =

The base for REST resources of this class

"packages"
RSRC_LIST_KEY =

the hash key used for the JSON list output of all objects in the JSS

:packages
RSRC_OBJECT_KEY =

The hash key used for the JSON object output. It’s also used in various error messages

:package
VALID_DATA_KEYS =

these keys, as well as :id and :name, are present in valid API JSON data for this class

[:fill_existing_users, :fill_user_template, :reboot_required ]
DIST_POINT_PKGS_FOLDER =

The pkg storage folder on the distribution point

"Packages"
CPU_TYPES =

The possible values for cpu_type (required_processor) in a JSS package

["None", "x86", "ppc"]
PRIORITIES =

the possible priorities

(1..20)
DEFAULT_PRIORITY =

the default priority, since one is needed for making new pkgs

10
DEFAULT_PROCESSOR =

by default, no processor requirement

"None"
DO_NOT_INSTALL =

When we shouldn’t install anything (e.g. switch w/package)

"Do Not Install"
DB_TABLE =

The table in the database for this object

"packages"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(args = {}) ⇒ Package

Returns a new instance of Package.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/jss/api_object/package.rb', line 168

def initialize (args = {})

  super

  ### now we have pkg_data with something in it, so fill out the instance vars
  @allow_uninstalled = @init_data[:allow_uninstalled]
  @boot_volume_required = @init_data[:boot_volume_required]
  @category = JSS::APIObject.get_name(@init_data[:category])
  @category = nil if @category.to_s.casecmp("No category assigned") == 0
  @filename = @init_data[:filename] || @init_data[:name]
  @fill_existing_users = @init_data[:fill_existing_users]
  @fill_user_template = @init_data[:fill_user_template]
  @info = @init_data[:info]
  @install_if_reported_available = @init_data[:install_if_reported_available]
  @notes = @init_data[:notes]
  @os_requirements = @init_data[:os_requirements].split(/\s*,\s*/) if @init_data[:os_requirements]
  @os_requirements ||= []

  @priority = @init_data[:priority] || DEFAULT_PRIORITY
  @reboot_required = @init_data[:reboot_required]
  @required_processor = @init_data[:required_processor] || DEFAULT_PROCESSOR
  @required_processor = nil if @required_processor.to_s.casecmp('none') == 0
  @send_notification = @init_data[:send_notification]
  @switch_with_package = @init_data[:switch_with_package] || DO_NOT_INSTALL

  # the receipt is the filename with any .zip extension removed.
  @receipt = @filename ? (JSS::Client::RECEIPTS_FOLDER + @filename.to_s.sub(/.zip$/, '')) : nil
end

Instance Attribute Details

#allow_uninstalledBoolean Also known as: removable, removable?



141
142
143
# File 'lib/jss/api_object/package.rb', line 141

def allow_uninstalled
  @allow_uninstalled
end

#boot_volume_requiredBoolean Also known as: boot, boot?



156
157
158
# File 'lib/jss/api_object/package.rb', line 156

def boot_volume_required
  @boot_volume_required
end

#categoryString



144
145
146
# File 'lib/jss/api_object/package.rb', line 144

def category
  @category
end

#filenameString



117
118
119
# File 'lib/jss/api_object/package.rb', line 117

def filename
  @filename
end

#fill_existing_usersBoolean Also known as: feu, feu?



123
124
125
# File 'lib/jss/api_object/package.rb', line 123

def fill_existing_users
  @fill_existing_users
end

#fill_user_templateBoolean Also known as: fut, fut?



126
127
128
# File 'lib/jss/api_object/package.rb', line 126

def fill_user_template
  @fill_user_template
end

#infoString



147
148
149
# File 'lib/jss/api_object/package.rb', line 147

def info
  @info
end

#install_if_reported_availableBoolean Also known as: if_in_swupdate, if_in_swupdate?



153
154
155
# File 'lib/jss/api_object/package.rb', line 153

def install_if_reported_available
  @install_if_reported_available
end

#need_to_updateBoolean (readonly) Originally defined in module Updatable

#notesString



150
151
152
# File 'lib/jss/api_object/package.rb', line 150

def notes
  @notes
end

#os_requirementsArray<String> Also known as: oses



132
133
134
# File 'lib/jss/api_object/package.rb', line 132

def os_requirements
  @os_requirements
end

#priorityInteger



159
160
161
# File 'lib/jss/api_object/package.rb', line 159

def priority
  @priority
end

#reboot_requiredBoolean Also known as: reboot, reboot?



129
130
131
# File 'lib/jss/api_object/package.rb', line 129

def reboot_required
  @reboot_required
end

#receiptPathname (readonly)



120
121
122
# File 'lib/jss/api_object/package.rb', line 120

def receipt
  @receipt
end

#required_processorString Also known as: cpu_type



135
136
137
# File 'lib/jss/api_object/package.rb', line 135

def required_processor
  @required_processor
end

#send_notificationBoolean Also known as: notify



162
163
164
# File 'lib/jss/api_object/package.rb', line 162

def send_notification
  @send_notification
end

#switch_with_packageString



138
139
140
# File 'lib/jss/api_object/package.rb', line 138

def switch_with_package
  @switch_with_package
end

Instance Method Details

#createInteger Originally defined in module Creatable

Create a new object in the JSS.

#delete(delete_file: false, rw_pw: nil, unmount: true) ⇒ Object

Delete this package from the JSS, optionally deleting the master dist point file also.



640
641
642
643
# File 'lib/jss/api_object/package.rb', line 640

def delete  (delete_file: false, rw_pw: nil, unmount: true)
  super()
  delete_master_file(rw_pw,  unmount) if delete_file
end

#delete_master_file(rw_pw, unmount = true) ⇒ Boolean

Delete the filename from the master distribution point, if it exists.

If you’ll be uploading several files you can specify unmount as false, and do it manually when all are finished.



616
617
618
619
620
621
622
623
624
625
626
627
# File 'lib/jss/api_object/package.rb', line 616

def delete_master_file (rw_pw, unmount = true)
  mdp = JSS::DistributionPoint.master_distribution_point
  file = mdp.mount(rw_pw, :rw) + "#{DIST_POINT_PKGS_FOLDER}/#{@filename}"
  if file.exist?
    file.delete
    did_it = true
  else
    did_it = false
  end # if exists
  mdp.unmount if unmount
  return did_it
end

#install(args = {}) ⇒ Boolean

TODO:

deal with cert-based https authentication in dist points

Note:

This code must be run as root to install packages

Install this package via the jamf binary ‘install’ command from the distribution point for this machine. See DistributionPoint.my_distribution_point

The read-only or http passwd for the dist. point must be provided, except for non-authenticated http downloads)

Options Hash (args):

  • :ro_pw (String)

    the read-only or http password for the distribution point for the local machine (http will be used if available, and may not need a pw)

  • :target (String, Pathname)

    The drive on which to install the package, defaults to ‘/’

  • :verbose (Boolean)

    be verbose to stdout, defaults to false

  • :feu (Boolean)

    fill existing users, defaults to false

  • :fut (Boolean)

    fill user template, defaults to false

  • :unmount (Boolean)

    unmount the distribution point when finished?(if we mounted it), defaults to false

  • :no_http (Boolean)

    don’t use http downloads even if they are enabled for the dist. point.

  • :alt_download_url (String)

    Use this url for an http download, regardless of distribution point settings. This can be used to access Cloud Distribution Points if the fileshare isn’t available. The URL should already be ur The package filename will be removed or appended as needed.

Raises:



685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
# File 'lib/jss/api_object/package.rb', line 685

def install (args = {})

  raise JSS::UnsupportedError, "You must have root privileges to install packages" unless JSS.superuser?

  args[:target] ||= '/'

  ro_pw = args[:ro_pw]

  # as of Casper 9.72, with http downloads, the jamf binary requires
  # the filename must be at the  end of the -path url, but before 9.72
  # it can't be.
  # e.g.
  #    in  <9.72:  jamf install  -package foo.pkg -path http://mycasper.myorg.edu/CasperShare/Packages
  # but
  #    in >=9.72:  jamf install  -package foo.pkg -path http://mycasper.myorg.edu/CasperShare/Packages/foo.pkg
  #
  append_at_vers = JSS.parse_jss_version("9.72")[:version]
  our_vers = JSS.parse_jss_version(JSS::API.server.raw_version)[:version]
  no_filename_in_url = (our_vers < append_at_vers)

  # use a provided alternative url for an http download
  if args[:alt_download_url]

    # we'll re-add the filename below if needed.
    src_path = args[:alt_download_url].chomp "/#{@filename}"

  # use our appropriate dist. point for download
  else
    mdp = JSS::DistributionPoint.my_distribution_point

    ### how do we access our dist. point? with http?
    if mdp.http_downloads_enabled and (not args[:no_http])
      using_http = true
      src_path = mdp.http_url
      if mdp.username_password_required
        raise JSS::MissingDataError, "No password provided for http download" unless ro_pw
        raise JSS::InvaldDatatError, "Incorrect password for http access to distribution point." unless mdp.check_pw(:http, ro_pw)
        # insert the name and pw into the uri
        # reserved_chars = Regexp.new("[^#{URI::REGEXP::PATTERN::UNRESERVED}]") # we'll escape all the chars that aren't unreserved
        src_path = src_path.sub(%r{(https?://)(\S)}, "#{$1}#{CGI.escape mdp.http_username}:#{CGI.escape ro_pw}@#{$2}")
      end

    # or with filesharing?
    else
      using_http = false
      src_path = mdp.mount(ro_pw)
    end

    # look at the pkgs folder
    src_path += "#{DIST_POINT_PKGS_FOLDER}/"
  end # if args[:alt_download_url]

  if using_http
    src_path += "#{@filename}" unless no_filename_in_url
  end

  ### are we doing "fill existing users" or "fill user template"?
  do_feu = args[:feu] ? "-feu" : ""
  do_fut = args[:fut] ? "-fut" : ""

  ### the install args for jamf
  command_args = "-package '#{@filename}' -path '#{src_path}'  -target '#{args[:target]}' #{do_feu} #{do_fut} -showProgress -verbose"

  ### run it via a client cmd
  install_out = JSS::Client.run_jamf :install, command_args, args[:verbose]

  install_out =~ %r{<exitCode>(\d+)</exitCode>}
  install_exit = $1 ? $1.to_i : nil
  install_exit ||= $?.exitstatus


  if (args.include? :unmount)
    mdp.unmount unless using_http
  end

  return install_exit == 0 ? true : false
end

#installed?Boolean

Is this packaged installed on the current machine (via casper)? We just look for the receipt, which is the @filename less any possible .zip extension.



503
504
505
# File 'lib/jss/api_object/package.rb', line 503

def installed?
  @receipt.file?
end

#name=(newname) ⇒ void Originally defined in module Updatable

This method returns an undefined value.

Change the name of this item Remember to #update to push changes to the server.

#os_ok?(os = nil) ⇒ Boolean

Is a given OS OK for this package based on its @os_requirements?



396
397
398
# File 'lib/jss/api_object/package.rb', line 396

def os_ok? (os = nil)
  JSS.os_ok? @os_requirements, os
end

#processor_ok?(processor = nil) ⇒ Boolean

Is a given processor OK for this package based on its @required_processor?



459
460
461
# File 'lib/jss/api_object/package.rb', line 459

def processor_ok? (processor = nil)
  JSS.processor_ok? @required_processor, processor
end

#typeSymbol

What type of package is this?



806
807
808
809
810
811
812
# File 'lib/jss/api_object/package.rb', line 806

def type
  case @filename
  when /\.m?pkg(\.zip)?$/ then :pkg
  when /\.dmg$/ then :dmg
  else :unknown
  end
end

#uninstall(args = {}) ⇒ Process::Status

Note:

This code must be run as root to uninstall packages

Causes the pkg to be uninstalled via the jamf command.

Options Hash (args):

  • :target (String, Pathname)

    The drive from which to uninstall the package, defaults to ‘/’

  • :verbose (Boolean)

    be verbose to stdout, defaults to false

  • :feu (Boolean)

    fill existing users, defaults to false

  • :fut (Boolean)

    fill user template, defaults to false

Raises:



780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
# File 'lib/jss/api_object/package.rb', line 780

def uninstall (args = {})

  raise JSS::UnsupportedError, \
    "This package cannot be uninstalled. Please use CasperAdmin to index it and allow uninstalls" unless removable?
  raise JSS::UnsupportedError, "You must have root privileges to uninstall packages" unless JSS.superuser?
  args[:target] ||= '/'

  ### are we doing "fill existing users" or "fill user template"?
  do_feu = args[:feu] ? "-feu" : ""
  do_fut = args[:fut] ? "-fut" : ""

  ### use jamf binary to uninstall the pkg
  jamf_opts = "-target '#{args[:target]}' -id '#{@id}' #{do_feu} #{do_fut}"

  ### run it via a client
  uninstall_out = JSS::Client.run_jamf "uninstall", jamf_opts, args[:verbose]

  return $?
end

#updateBoolean Originally defined in module Updatable

Save changes to the JSS

#update_master_filename(old_file_name, new_file_name, rw_pw, unmount = true) ⇒ nil

Change the name of a package file on the master distribution point.



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/jss/api_object/package.rb', line 584

def update_master_filename(old_file_name, new_file_name, rw_pw , unmount = true )
  raise JSS::NoSuchItemError, "#{old_file_name} does not exist in the jss." unless @in_jss
  mdp = JSS::DistributionPoint.master_distribution_point
  pkgs_dir =  mdp.mount(rw_pw, :rw) + "#{DIST_POINT_PKGS_FOLDER}"
  old_file = pkgs_dir + old_file_name
  new_file = pkgs_dir + new_file_name
  if new_file.extname.empty? 
  ### use the extension of the original file.
    new_file = pkgs_dir + (new_file_name + old_file.extname)
  end
  if old_file.exist?
    old_file.rename new_file
  else
    raise JSS::NoSuchItemError, "Original file not found on the master distribution point at #{DIST_POINT_PKGS_FOLDER}/#{old_file_name}."
  end # if exist
  mdp.unmount if unmount
  return nil
end

#upload_master_file(local_file_path, rw_pw, unmount = true) ⇒ void

This method returns an undefined value.

Upload a locally-readable file to the master distribution point. If the file is a directory (like a bundle .pk/.mpkg) it will be zipped before uploading and the @filename will be adjusted accordingly

If you’ll be uploading several files you can specify unmount as false, and do it manually when all are finished with JSS::DistributionPoint.master_distribution_point.unmount



524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/jss/api_object/package.rb', line 524

def upload_master_file (local_file_path, rw_pw, unmount = true)

  raise JSS::NoSuchItemError, "Please create this package in the JSS before uploading it." unless @in_jss

  mdp = JSS::DistributionPoint.master_distribution_point
  destination = mdp.mount(rw_pw, :rw) +"#{DIST_POINT_PKGS_FOLDER}/#{@filename}"

  local_path = Pathname.new local_file_path
  raise JSS::NoSuchItemError, "Local file '#{@local_file}' doesn't exist" unless local_path.exist?

  ### should we zip it?
  if local_path.directory?
    begin
      zipdir = Pathname.new "/tmp/jssgemtmp-#{Time.new.strftime "%Y%m%d%H%M%S"}-#{$$}"
      zipdir.mkpath
      zipdir.chmod 0700
      zipfile = zipdir + (local_path.basename.to_s + ".zip")

      ### go to the same dir as the local file
      wd = Dir.pwd
      Dir.chdir local_path.parent

      ### the contents of the zip file have to have the same name as the zip file itself (minus the .zip)
      ### so temporarily rename the source
      local_path.rename(local_path.parent + @filename)
      raise "There was a problem zipping the pkg bundle" unless system "/usr/bin/zip -qr '#{zipfile}' '#{@filename}'"

    ensure
      ### rename the source to the original name
      (local_path.parent + @filename).rename local_path if  (local_path.parent + @filename).exist?
      ### go back where we started
      Dir.chdir wd
    end # begin

    ### update our info
    local_path = zipfile

    self.filename = zipfile.basename.to_s

  end # if directory
  self.update
  FileUtils.copy_entry local_path, destination

  mdp.unmount if unmount
end