Method: Jamf::ManagementHistory::ClassMethods#app_store_app_history

Defined in:
lib/jamf/api/classic/api_objects/management_history.rb

#app_store_app_history(ident, status = nil, api: nil, cnx: Jamf.cnx) ⇒ Array Also known as: managed_app_history

Wrapper for app store history for both computers and mobile devices

Parameters:

  • ident (Type)

    The identifier for the object - id, name, sn, udid, etc.

  • status (Symbol) (defaults to: nil)

    Return only the :installed, :pending, or :failed apps

  • cnx (Jamf::Connection) (defaults to: Jamf.cnx)

    The API connection to use for the query defaults to the currently active connection

Returns:

  • (Array)

    An array of MacAppStoreApp or MobileDeviceApp



468
469
470
471
472
473
474
475
476
# File 'lib/jamf/api/classic/api_objects/management_history.rb', line 468

def app_store_app_history(ident, status = nil, api: nil, cnx: Jamf.cnx)
  cnx = api if api

  if self == Jamf::MobileDevice
    mobile_device_app_history(ident, status, cnx: cnx)
  else
    mac_app_store_app_history(ident, status, cnx: cnx)
  end
end