Class: Jamf::AdvancedMobileDeviceSearch

Inherits:
AdvancedSearch
  • Object
show all
Defined in:
lib/jamf/api/classic/api_objects/advanced_mobile_device_search.rb

Overview

An AdvancedComputerSearch in the JSS

Constant Summary collapse

RSRC_BASE =

The base for REST resources of this class

'advancedmobiledevicesearches'.freeze
RSRC_LIST_KEY =

the hash key used for the JSON list output of all objects in the JSS

:advanced_mobile_device_searches
RSRC_OBJECT_KEY =

The hash key used for the JSON object output. It's also used in various error messages

:advanced_mobile_device_search
RESULT_CLASS =

what kind of thing is returned by this search?

Jamf::MobileDevice
RESULT_ID_FIELDS =

what data fields come back along with the display fields for each mobiledevices?

%i[id name udid].freeze
OBJECT_HISTORY_OBJECT_TYPE =

the object type for this object in the object history table. See Jamf::APIObject#add_object_history_entry

71