Class: Jamf::Building

Inherits:
CollectionResource show all
Extended by:
BulkDeletable
Includes:
ChangeLog
Defined in:
lib/jamf/api/resources/collection_resources/building.rb

Overview

A building defined in the JSS

Constant Summary collapse

RSRC_VERSION =

Constants

'v1'.freeze
RSRC_PATH =
'buildings'.freeze
OBJECT_MODEL =

Object Model / Attributes See APIObject class documentation for details of how the OBJECT_MODEL hash works.

{

  # @!attribute [r] id
  #   @return [Integer]
  id: {
    class: :j_id,
    identifier: :primary,
    readonly: true
  },

  # @!attribute name
  #   @return [String]
  name: {
    class: :string,
    identifier: true,
    validator: :non_empty_string,
    required: true,
    filter_key: true
  },

  # @!attribute street1
  #   @return [String]
  streetAddress1: {
    class: :string,
    filter_key: true
  },

  # @!attribute street2
  #   @return [String]
  streetAddress2: {
    class: :string,
    filter_key: true
  },

  # @!attribute city
  #   @return [String]
  city: {
    class: :string,
    filter_key: true
  },

  # @!attribute state_province
  #   @return [String]
  stateProvince: {
    class: :string,
    aliases: %i[state province],
    filter_key: true
  },

  # @!attribute zip_postal_code
  #   @return [String]
  zipPostalCode: {
    class: :string,
    aliases: %i[zip zipcode zip_code postal_code postalcode],
    filter_key: true
  },

  # @!attribute country
  #   @return [String]
  country: {
    class: :string,
    filter_key: true
  }
}.freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

This class inherits a constructor from Jamf::JSONObject

Instance Attribute Details

#cityString



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 86

#countryString



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 109

#idInteger (readonly)



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 54

#nameString



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 62

#state_provinceString



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 93

#street1String



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 72

#street2String



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 79

#zip_postal_codeString



# File 'lib/jamf/api/resources/collection_resources/building.rb', line 101

Class Method Details

.bulk_delete(ids, cnx: Jamf.cnx) ⇒ Array<Jamf::Connection::APIError::ErrorInfo] Info about any ids that failed to be deleted. Originally defined in module BulkDeletable

Delete multiple objects by providing an array of their

Instance Method Details

#add_change_log_note(note, cnx: Jamf.cnx) ⇒ void Originally defined in module ChangeLog

This method returns an undefined value.

Add a note to this resource's change log.

If the change history has been cached already, the cache is flushed after adding the note.

#change_log(sort: nil, filter: nil, paged: nil, page_size: nil, refresh: false, cnx: Jamf.cnx) ⇒ Array<Jamf::ChangeLogEntry> Originally defined in module ChangeLog

The change and note history for this resource. This is a collection of objects as a sub-resource of some primary resource. As such, retriving the change log returns an array of objects, and can be paged, sorted and filtered.

This method is very similar to CollectionResource.all, see the docs for that method for more details

successive page.

#change_log_count(cnx: Jamf.cnx) ⇒ Integer Originally defined in module ChangeLog

how many change log entries are there? needed when using paged #change_log calls

#next_page_of_change_logArray<Jamf::ChangeHistoryEntry> Originally defined in module ChangeLog

Fetch the next page of a paged #change_log request Returns an empty array if there's been no paged request or if the last one has no more pages.