Class: Jamf::MobileDeviceConfigurationProfile

Inherits:
ConfigurationProfile
  • Object
show all
Defined in:
lib/jamf/api/classic/api_objects/mobile_device_configuration_profile.rb

Constant Summary collapse

RSRC_BASE =

The base for REST resources of this class

'mobiledeviceconfigurationprofiles'.freeze
RSRC_LIST_KEY =

the hash key used for the JSON list output of all objects in the JSS

:configuration_profiles
RSRC_OBJECT_KEY =

The hash key used for the JSON object output. It's also used in various error messages

:configuration_profile
OBJECT_HISTORY_OBJECT_TYPE =

the object type for this object in the object history table. See APIObject#add_object_history_entry

22
SCOPE_TARGET_KEY =

Our scopes deal with mobile_devices

:mobile_devices

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileDeviceConfigurationProfile

See Jamf::APIObject#initialize



46
47
48
49
# File 'lib/jamf/api/classic/api_objects/mobile_device_configuration_profile.rb', line 46

def initialize(**args)
  super
  @redeploy_days_before_certificate_expires = @main_subset[:redeploy_days_before_certificate_expires]
end

Instance Attribute Details

#redeploy_days_before_certificate_expiresInteger

should this profile be automatically re-installed?

Returns:

  • (Integer)

    how many days before a cert payload expires



39
40
41
# File 'lib/jamf/api/classic/api_objects/mobile_device_configuration_profile.rb', line 39

def redeploy_days_before_certificate_expires
  @redeploy_days_before_certificate_expires
end