Class: Jamf::OAPISchemas::DssDeclarations

Inherits:
Jamf::OAPIObject show all
Defined in:
lib/jamf/api/jamf_pro/oapi_schemas/dss_declarations.rb

Overview

OAPI Object Model and Enums for: DssDeclarations

This class was automatically generated from the api/schema URL path on a Jamf Pro server version 11.14.1-t1740408745756

This class may be used directly, e.g instances of other classes may use instances of this class as one of their own properties/attributes.

It may also be used as a superclass when implementing Jamf Pro API Resources in ruby-jss. The subclasses include appropriate mixins, and should expand on the basic functionality provided here.

Container Objects: Other object models that use this model as the value in one of their attributes.

Sub Objects: Other object models used by this model's attributes.

  • Jamf::OAPISchemas::DssDeclaration

Endpoints and Privileges: API endpoints and HTTP operations that use this object model, and the Jamf Pro privileges needed to access them.

  • '/v1/dss-declarations/id:GET' needs permissions:
    • Read Mobile Devices
    • Read Computers
  • '/v1/managed-software-updates/plans/id/declarations:GET' needs permissions:
    • Read Managed Software Updates
    • Read Computers
    • Read Mobile Devices

Constant Summary collapse

OAPI_PROPERTIES =
{

  # @!attribute declarations
  #   @return [Array<Jamf::OAPISchemas::DssDeclaration>]
  declarations: {
    class: Jamf::OAPISchemas::DssDeclaration,
    multi: true
  }

}

Instance Attribute Summary collapse

Constructor Details

This class inherits a constructor from Jamf::OAPIObject

Instance Attribute Details

#declarationsArray<Jamf::OAPISchemas::DssDeclaration>



# File 'lib/jamf/api/jamf_pro/oapi_schemas/dss_declarations.rb', line 54