Class: Jamf::OAPISchemas::ExtensionAttributes
- Inherits:
-
Jamf::OAPIObject
- Object
- Jamf::OAPIObject
- Jamf::OAPISchemas::ExtensionAttributes
- Defined in:
- lib/jamf/api/jamf_pro/oapi_schemas/extension_attributes.rb
Overview
OAPI Object Model and Enums for: ExtensionAttributes
This class was automatically generated from the api/schema URL path on a Jamf Pro server version 11.9.2-t1726753918
This class may be used directly, e.g instances of other classes may use instances of this class as one of their own properties/attributes.
It may also be used as a superclass when implementing Jamf Pro API Resources in ruby-jss. The subclasses include appropriate mixins, and should expand on the basic functionality provided here.
Container Objects: Other object models that use this model as the value in one of their attributes.
Sub Objects: Other object models used by this model's attributes.
Endpoints and Privileges: API endpoints and HTTP operations that use this object model, and the Jamf Pro privileges needed to access them.
Constant Summary collapse
- DATA_TYPE_OPTIONS =
Enums used by this class or others
[ 'INTEGER', 'STRING', 'DATE' ]
- OAPI_PROPERTIES =
{ # Unique Id for Computer Extension Attribute. # @!attribute [r] id # @return [String] id: { class: :j_id, identifier: :primary, readonly: true }, # Display name for the extension attribute. # @!attribute name # @return [String] name: { class: :string, required: true }, # Description for the extension attribute. # @!attribute description # @return [String] description: { class: :string }, # Type of data being collected. # @!attribute dataType # @return [String] dataType: { class: :string, required: true, enum: DATA_TYPE_OPTIONS } }
Instance Attribute Summary collapse
Constructor Details
This class inherits a constructor from Jamf::OAPIObject
Instance Attribute Details
#id ⇒ String (readonly)
|
|
# File 'lib/jamf/api/jamf_pro/oapi_schemas/extension_attributes.rb', line 75
|