Class: Jamf::OAPISchemas::ManagedSoftwareUpdatePlanGroupPost

Inherits:
Jamf::OAPIObject show all
Defined in:
lib/jamf/api/jamf_pro/oapi_schemas/managed_software_update_plan_group_post.rb

Overview

OAPI Object Model and Enums for: ManagedSoftwareUpdatePlanGroupPost

This class was automatically generated from the api/schema URL path on a Jamf Pro server version 11.14.1-t1740408745756

This class may be used directly, e.g instances of other classes may use instances of this class as one of their own properties/attributes.

It may also be used as a superclass when implementing Jamf Pro API Resources in ruby-jss. The subclasses include appropriate mixins, and should expand on the basic functionality provided here.

Container Objects: Other object models that use this model as the value in one of their attributes.

Sub Objects: Other object models used by this model's attributes.

  • Jamf::OAPISchemas::PlanGroupPost
  • Jamf::OAPISchemas::PlanConfigurationPost

Endpoints and Privileges: API endpoints and HTTP operations that use this object model, and the Jamf Pro privileges needed to access them.

  • '/v1/managed-software-updates/plans/group:POST' needs permissions:
    • Create Managed Software Updates
    • Read Computers
    • Read Mobile Devices
    • Read Smart Computer Groups
    • Read Static Computer Groups
    • Read Smart Mobile Device Groups
    • Read Static Mobile Device Groups
    • Send Computer Remote Command to Download and Install OS X Update
    • Send Mobile Device Remote Command to Download and Install iOS Update

Constant Summary collapse

OAPI_PROPERTIES =
{

  # @!attribute group
  #   @return [Jamf::OAPISchemas::PlanGroupPost]
  group: {
    class: Jamf::OAPISchemas::PlanGroupPost,
    required: true
  },

  # @!attribute config
  #   @return [Jamf::OAPISchemas::PlanConfigurationPost]
  config: {
    class: Jamf::OAPISchemas::PlanConfigurationPost,
    required: true
  }

}

Instance Attribute Summary collapse

Constructor Details

This class inherits a constructor from Jamf::OAPIObject

Instance Attribute Details

#configJamf::OAPISchemas::PlanConfigurationPost



# File 'lib/jamf/api/jamf_pro/oapi_schemas/managed_software_update_plan_group_post.rb', line 65

#groupJamf::OAPISchemas::PlanGroupPost



# File 'lib/jamf/api/jamf_pro/oapi_schemas/managed_software_update_plan_group_post.rb', line 58