Refresh

This website rubydoc.info/gems/ruby-jss/Jamf/TimeoutError is currently offline. Cloudflare\'s Always Online™ shows a snapshot of this web page from the Internet Archive\'s Wayback Machine. To check for the live version, click Refresh.

Exception: Jamf::TimeoutError

Inherits:
RuntimeError
  • Object
show all
Defined in:
lib/jamf/exceptions.rb

Overview

TimeoutError - raise this when we try to do and it times out