Class: Jamf::UserGroup
- Defined in:
- lib/jamf/api/classic/api_objects/user_group.rb
Overview
A Mobile Device group in the JSS
See also the parent class Jamf::Group
Constant Summary collapse
- RSRC_BASE =
The base for REST resources of this class
'usergroups'- RSRC_LIST_KEY =
the hash key used for the JSON list output of all objects in the JSS
:user_groups- RSRC_OBJECT_KEY =
The hash key used for the JSON object output. It's also used in various error messages
:user_group- MEMBER_CLASS =
this allows the parent Group class to do things right
Jamf::User
- ADD_MEMBERS_ELEMENT =
the XML element for immediate member additions via PUT
'user_additions'.freeze
- REMOVE_MEMBERS_ELEMENT =
the XML element for immediate member removals via PUT
'user_deletions'.freeze
- OBJECT_HISTORY_OBJECT_TYPE =
the object type for this object in the object history table. See APIObject#add_object_history_entry
54
Instance Method Summary collapse
-
#member_email_addresses ⇒ Array<String>
Return an array of the email addresses of users in this group.
-
#member_full_names ⇒ Array<String>
Return an array of the full names of users in this group.
-
#member_phone_numbers ⇒ Array<String>
Return an array of the phone numbers of users in this group.
-
#member_usernames ⇒ Array<String>
Return an array of the usernames of users in this group.
Instance Method Details
#member_email_addresses ⇒ Array<String>
Return an array of the email addresses of users in this group
118 119 120 |
# File 'lib/jamf/api/classic/api_objects/user_group.rb', line 118 def member_email_addresses @members.map { |m| m[:email_address] } end |
#member_full_names ⇒ Array<String>
Return an array of the full names of users in this group
100 101 102 |
# File 'lib/jamf/api/classic/api_objects/user_group.rb', line 100 def member_full_names @members.map { |m| m[:full_name] } end |