Method: JSS::MDM#unmanage_device
- Defined in:
- lib/jss/api_object/mdm.rb
#unmanage_device ⇒ Object Also known as: remove_mdm_profile
Send an unmanage device command to this object
NOTE: when used with computers, the mdm profile will probably be re-installed immediately unless the computer is also no longer managed by Jamf Pro itself. To fully unmanage a computer, use the Computer#make_unmanaged instance method.
1053 1054 1055 |
# File 'lib/jss/api_object/mdm.rb', line 1053 def unmanage_device self.class.unmanage_device @id, api: @api end |