Method: JSS::Policy#client_side_limitations
- Defined in:
- lib/jss/api_object/policy.rb
#client_side_limitations ⇒ Hash (readonly)
The client-side limitations of this policy.
The keys are:
-
:no_execute_on - An array of short day names as strings, e.g. [“Sun”, “Mon”, “Tue”]
-
:no_execute_start - Time
-
:no_execute_end - Time
-
:network_connection - String
The data for the first three comes from the API in the date_time_limitations hash of the general section. The fourth comes from the network_requirements of the general section of the API, but the UI shows them in the Client Side Limitations area.
This attribute is just for convience and consistency, and just refers to the data in their API locations
377 378 379 |
# File 'lib/jss/api_object/policy.rb', line 377 def client_side_limitations @client_side_limitations end |