Method: JSS::Purchasable#purchasing
- Defined in:
- lib/jss/api_object/purchasable.rb
#purchasing ⇒ Hash<String>
All the purchasing data in a Hash, as it comes from the API.
The reason it isn’t stored this way is to prevent editing of the hash directly.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/jss/api_object/purchasable.rb', line 240 def purchasing { :applecare_id => @applecare_id, :is_leased => @is_leased, :is_purchased => @is_purchased, :lease_expires => @lease_expires, :life_expectancy => @life_expectancy, :po_date => @po_date, :po_number => @po_number, :purchase_price => @purchase_price, :purchasing_account => @purchasing_account, :purchasing_contact => @purchasing_contact, :vendor => @vendor, :warranty_expires => @warranty_expires, } end |