Method: JSS::DistributionPoint#initialize
- Defined in:
- lib/jss/api_object/distribution_point.rb
#initialize(args = {}) ⇒ DistributionPoint
As well as the standard :id, :name, and :data, you can instantiate this class with :id => :master, in which case you’ll get the Master Distribution Point as defined in the JSS. An error will be raised if one hasn’t been defined.
You can also do this more easily by calling JSS.master_distribution_point
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/jss/api_object/distribution_point.rb', line 247 def initialize(args = {}) @init_data = nil ### looking for master? if args[:id] == :master self.class.all_ids.each do |id| @init_data = JSS::API.get_rsrc("#{RSRC_BASE}/id/#{id}")[RSRC_OBJECT_KEY] if @init_data[:is_master] @id = @init_data[:id] @name = @init_data[:name] break end # if data is master @init_data = nil end # each id end # if args is master if @init_data.nil? super(args) end @ip_address = @init_data[:ip_address] @local_path = @init_data[:local_path] @enable_load_balancing = @init_data[:enable_load_balancing] @failover_point = @init_data[:failover_point] @is_master = @init_data[:is_master] @connection_type = @init_data[:connection_type] @share_port = @init_data[:share_port] @share_name = @init_data[:share_name] @workgroup_or_domain = @init_data[:workgroup_or_domain] @read_write_username = @init_data[:read_write_username] @read_write_password_sha256 = @init_data[:read_write_password_sha256] @read_only_username = @init_data[:read_only_username] @read_only_password_sha256 = @init_data[:read_only_password_sha256] @ssh_username = @init_data[:ssh_username] @ssh_password_sha256 = @init_data[:ssh_password_sha256] @http_username = @init_data[:http_username] @http_password_sha256 = @init_data[:http_password_sha256] @http_downloads_enabled = @init_data[:http_downloads_enabled] @protocol = @init_data[:protocol] @port = @init_data[:port] @context = @init_data[:context] @no_authentication_required = @init_data[:no_authentication_required] @certificate_required = @init_data[:certificate_required] @username_password_required = @init_data[:username_password_required] @certificate = @init_data[:certificate] @http_url = @init_data[:http_url] @failover_point_url = @init_data[:failover_point_url] @port = @init_data[:ssh_password] ### Note, as of Casper 9.3: ### :management_password_md5=>"xxxxx" ### and ### :management_password_sha256=> "xxxxxxxxxx" ### Are the read/write password ### ### An empty passwd is ### MD5 = d41d8cd98f00b204e9800998ecf8427e ### SHA256 = e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855 ### ### Seemms the read-only pw isn't available in the API ### if we mount for fileservice, where's the mountpoint? @mountpoint = Pathname.new "/Volumes/CasperDistribution-id-#{@id}" end |