Module: Jamf::DataDependency::ClassMethods
- Defined in:
- lib/jamf/api/jamf_pro/mixins/data_dependency.rb
Overview
Class Methods
Class Method Summary collapse
Instance Method Summary collapse
-
#data_dependency(ident, cnx: Jamf.cnx) ⇒ Array<Hash>
Get the dependencies for the specified id.
Class Method Details
Instance Method Details
#data_dependency(ident, cnx: Jamf.cnx) ⇒ Array<Hash>
Get the dependencies for the specified id. This is a list of objects that use this object and would prevent if from being deleted
54 55 56 57 |
# File 'lib/jamf/api/jamf_pro/mixins/data_dependency.rb', line 54 def data_dependency(ident, cnx: Jamf.cnx) id = valid_id(ident) cnx.jp_get("#{self::LIST_PATH}/#{id}/#{DATA_DEPENDENCY_ENDPOINT}")[:results] end |