Class: Jamf::MobileDeviceConfigurationProfile

Inherits:
ConfigurationProfile show all
Defined in:
lib/jamf/api/classic/api_objects/mobile_device_configuration_profile.rb

Constant Summary collapse

RSRC_BASE =

The base for REST resources of this class

'mobiledeviceconfigurationprofiles'.freeze
RSRC_LIST_KEY =

the hash key used for the JSON list output of all objects in the JSS

:configuration_profiles
RSRC_OBJECT_KEY =

The hash key used for the JSON object output. It’s also used in various error messages

:configuration_profile
OBJECT_HISTORY_OBJECT_TYPE =

the object type for this object in the object history table. See APIObject#add_object_history_entry

22
SCOPE_TARGET_KEY =

Our scopes deal with mobile_devices

:mobile_devices

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileDeviceConfigurationProfile

See Jamf::APIObject#initialize



64
65
66
67
# File 'lib/jamf/api/classic/api_objects/mobile_device_configuration_profile.rb', line 64

def initialize(**args)
  super
  @redeploy_days_before_certificate_expires = @main_subset[:redeploy_days_before_certificate_expires]
end

Instance Attribute Details

#iconJamf::Icon? Also known as: self_service_icon Originally defined in module SelfServable

#in_self_serviceBoolean (readonly) Also known as: in_self_service? Originally defined in module SelfServable

#need_to_updateBoolean (readonly) Originally defined in module Updatable

#redeploy_days_before_certificate_expiresInteger

should this profile be automatically re-installed?



57
58
59
# File 'lib/jamf/api/classic/api_objects/mobile_device_configuration_profile.rb', line 57

def redeploy_days_before_certificate_expires
  @redeploy_days_before_certificate_expires
end

#scopeObject Originally defined in module Scopable

Attribtues

#self_service_categoriesArray<Hash> (readonly) Originally defined in module SelfServable

Each Hash has these keys about the category

  • :id => [Integer] the JSS id of the category

  • :name => [String] the name of the category

Most objects also include one or both of these keys:

  • :display_in => [Boolean] should the item be displayed in this category in SSvc? (not MobDevConfProfiles)

  • :feature_in => [Boolean] should the item be featured in this category in SSVC? (macOS targets only)

#self_service_descriptionString Originally defined in module SelfServable

#self_service_display_nameString Also known as: self_service_dislay_name Originally defined in module SelfServable

#self_service_feature_on_main_pageBoolean Originally defined in module SelfServable

Only applicable to macOS targets

#self_service_force_users_to_view_descriptionBoolean Originally defined in module SelfServable

#self_service_install_button_textString Originally defined in module SelfServable

defaults to ‘Install’

#self_service_notification_messageString Originally defined in module SelfServable

#self_service_notification_subjectString Originally defined in module SelfServable

object name.

#self_service_notification_typeSymbol Originally defined in module SelfServable

#self_service_notifications_enabledBoolean Also known as: self_service_notifications_enabled? Originally defined in module SelfServable

#self_service_reinstall_button_textString Originally defined in module SelfServable

defaults to ‘Reinstall’

#self_service_reminder_frequencyInteger Originally defined in module SelfServable

#self_service_reminders_enabledBoolean Also known as: self_service_reminders_enabled? Originally defined in module SelfServable

#self_service_removal_passwordString (readonly) Originally defined in module SelfServable

#self_service_user_removableSymbol Originally defined in module SelfServable