Class: Jamf::OSXConfigurationProfile
- Defined in:
- lib/jamf/api/classic/api_objects/osx_configuration_profile.rb
Overview
An OS X Configuration Profile in the JSS.
Note that the profile payloads and the profile UUID cannot be edited or updated with this via this class. Use the web UI.
Constant Summary collapse
- RSRC_BASE =
The base for REST resources of this class
'osxconfigurationprofiles'.freeze
- RSRC_LIST_KEY =
the hash key used for the JSON list output of all objects in the JSS
:os_x_configuration_profiles- RSRC_OBJECT_KEY =
The hash key used for the JSON object output. It's also used in various error messages
:os_x_configuration_profile- SCOPE_TARGET_KEY =
Our scopes deal with computers
:computers- SELF_SERVICE_TARGET =
Our SelfService happens on OSX
:osx- LEVELS =
The possible values for :level
%w[user computer].freeze
- OBJECT_HISTORY_OBJECT_TYPE =
the object type for this object in the object history table. See APIObject#add_object_history_entry
4
Instance Attribute Summary collapse
-
#level ⇒ String
The level (user/computer) of this profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OSXConfigurationProfile
constructor
See Jamf::APIObject#initialize.
Constructor Details
#initialize(**args) ⇒ OSXConfigurationProfile
See Jamf::APIObject#initialize
63 64 65 66 |
# File 'lib/jamf/api/classic/api_objects/osx_configuration_profile.rb', line 63 def initialize(**args) super @level = @main_subset[:level] end |
Instance Attribute Details
#level ⇒ String
Returns the level (user/computer) of this profile.
56 57 58 |
# File 'lib/jamf/api/classic/api_objects/osx_configuration_profile.rb', line 56 def level @level end |