Class: Jamf::PatchInternalSource
- Defined in:
- lib/jamf/api/classic/api_objects/patch_internal_source.rb
Overview
An 'Internal' patch source. These sources are defined by Jamf themselves, as a part of the JSS, and cannot be created, modified or deleted.
Constant Summary collapse
- RSRC_BASE =
The base for REST resources of this class
'patchinternalsources'.freeze
- RSRC_LIST_KEY =
the hash key used for the JSON list output of all objects in the JSS
:patch_internal_sources- RSRC_OBJECT_KEY =
The hash key used for the JSON object output. It's also used in various error messages
:patch_internal_source